package com.xkrs.model.entity;

import javax.persistence.*;
import java.io.Serializable;
import java.time.LocalDateTime;


/**
 * SysUser 表实体类
 *
 * @author tajochen
 */
@Entity
@Table(name = "sys_user")
public class SysUserEntity implements Serializable {

    /**
     * 指定主键，建立自增序列，主键值取自序列
     */
    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "sys_user_seq_gen")
    @SequenceGenerator(name = "sys_user_seq_gen", sequenceName = "sys_user_id_seq", allocationSize = 1)
    private Integer id;

    /**
     * 用户名
     */
    @Column(length = 16, nullable = false, unique = true, columnDefinition = "varchar(16)")
    private String userName;

    /**
     * 用户真实姓名
     */
    @Column(length = 32, columnDefinition = "varchar(32)")
    private String reallyName;

    /**
     * 密码
     */
    @Column(length = 64, nullable = false, columnDefinition = "varchar(64)")
    private String password;

    @Column(length = 32, nullable = false, columnDefinition = "varchar(32)")
    private String salt;

    @Column(length = 16, unique = true, columnDefinition = "varchar(16)")
    private String telephone;

    @Column(length = 32, columnDefinition = "varchar(32)")
    private String countyCode;

    @Column(columnDefinition = "varchar(192)")
    private String signature;

    @Column(nullable = false)
    private Integer activeFlag;

    @Column(nullable = false, columnDefinition = "smallint")
    private Integer statusCode;

    @Column(nullable = false)
    private String addTime;

    private LocalDateTime lastEntryTime;

    @Column(nullable = false)
    private Integer deleteFlag;

    @Column(columnDefinition = "varchar(64)")
    private String lastEntryIp;

    /**
     * 账号的使用天数
     */
    private Integer dayNum;

    /**
     * 账号到期的时间
     */
    private String overTime;

    /**
     * 账号类别
     */
    @Column(length = 64, columnDefinition = "varchar(64)")
    private String accountType;

    @Column(length = 64, columnDefinition = "varchar(64)")
    private String countyName;

    /**
     * 登录次数
     */
    private Integer loginNum;

    /**
     * 用户最新登录时间
     */
    private String loginLastTime;

    /**
     * 注册时的UA
     */
    @Column(columnDefinition = "varchar(1024)")
    private String userAgent;

    /**
     * vip等级
     */
    private Integer vipLevel;

    /**
     * 是否接收短信
     */
    private Integer receiveSms;

    public SysUserEntity() {
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getReallyName() {
        return reallyName;
    }

    public void setReallyName(String reallyName) {
        this.reallyName = reallyName;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getSalt() {
        return salt;
    }

    public void setSalt(String salt) {
        this.salt = salt;
    }

    public String getTelephone() {
        return telephone;
    }

    public void setTelephone(String telephone) {
        this.telephone = telephone;
    }

    public String getCountyCode() {
        return countyCode;
    }

    public void setCountyCode(String countyCode) {
        this.countyCode = countyCode;
    }

    public String getSignature() {
        return signature;
    }

    public void setSignature(String signature) {
        this.signature = signature;
    }

    public Integer getActiveFlag() {
        return activeFlag;
    }

    public void setActiveFlag(Integer activeFlag) {
        this.activeFlag = activeFlag;
    }

    public Integer getStatusCode() {
        return statusCode;
    }

    public void setStatusCode(Integer statusCode) {
        this.statusCode = statusCode;
    }

    public String getAddTime() {
        return addTime;
    }

    public void setAddTime(String addTime) {
        this.addTime = addTime;
    }

    public LocalDateTime getLastEntryTime() {
        return lastEntryTime;
    }

    public void setLastEntryTime(LocalDateTime lastEntryTime) {
        this.lastEntryTime = lastEntryTime;
    }

    public Integer getDeleteFlag() {
        return deleteFlag;
    }

    public void setDeleteFlag(Integer deleteFlag) {
        this.deleteFlag = deleteFlag;
    }

    public String getLastEntryIp() {
        return lastEntryIp;
    }

    public void setLastEntryIp(String lastEntryIp) {
        this.lastEntryIp = lastEntryIp;
    }

    public Integer getDayNum() {
        return dayNum;
    }

    public void setDayNum(Integer dayNum) {
        this.dayNum = dayNum;
    }

    public String getOverTime() {
        return overTime;
    }

    public void setOverTime(String overTime) {
        this.overTime = overTime;
    }

    public String getAccountType() {
        return accountType;
    }

    public void setAccountType(String accountType) {
        this.accountType = accountType;
    }

    public String getCountyName() {
        return countyName;
    }

    public void setCountyName(String countyName) {
        this.countyName = countyName;
    }

    public Integer getLoginNum() {
        return loginNum;
    }

    public void setLoginNum(Integer loginNum) {
        this.loginNum = loginNum;
    }

    public String getLoginLastTime() {
        return loginLastTime;
    }

    public void setLoginLastTime(String loginLastTime) {
        this.loginLastTime = loginLastTime;
    }

    public String getUserAgent() {
        return userAgent;
    }

    public void setUserAgent(String userAgent) {
        this.userAgent = userAgent;
    }

    public Integer getVipLevel() {
        return vipLevel;
    }

    public void setVipLevel(Integer vipLevel) {
        this.vipLevel = vipLevel;
    }

    public Integer getReceiveSms() {
        return receiveSms;
    }

    public void setReceiveSms(Integer receiveSms) {
        this.receiveSms = receiveSms;
    }

    @Override
    public String toString() {
        return "SysUserEntity{" + "id=" + id + ", userName='" + userName + '\'' + ", reallyName='" + reallyName + '\'' + ", password='" + password + '\'' + ", salt='" + salt + '\'' + ", telephone='" + telephone + '\'' + ", countyCode='" + countyCode + '\'' + ", signature='" + signature + '\'' + ", activeFlag=" + activeFlag + ", statusCode=" + statusCode + ", addTime='" + addTime + '\'' + ", lastEntryTime=" + lastEntryTime + ", deleteFlag=" + deleteFlag + ", lastEntryIp='" + lastEntryIp + '\'' + ", dayNum=" + dayNum + ", overTime='" + overTime + '\'' + ", accountType='" + accountType + '\'' + ", countyName='" + countyName + '\'' + ", loginNum=" + loginNum + ", loginLastTime='" + loginLastTime + '\'' + ", userAgent='" + userAgent + '\'' + ", vipLevel=" + vipLevel + ", receiveSms=" + receiveSms + '}';
    }
}
